pub struct BraidzArchive<R: Read + Seek> {
pub metadata: BraidMetadata,
pub expected_fps: f64,
pub calibration_info: Option<CalibrationInfo>,
pub kalman_estimates_info: Option<KalmanEstimatesInfo>,
pub kalman_estimates_table: Option<Vec<KalmanEstimatesRow>>,
pub data_association: Option<Vec<DataAssocRow>>,
pub reconstruction_latency_hlog: Option<HistogramLog>,
pub reprojection_distance_hlog: Option<HistogramLog>,
pub cam_info: CamInfo,
pub data2d_distorted: Option<D2DInfo>,
pub image_sizes: Option<BTreeMap<String, (usize, usize)>>,
/* private fields */
}Expand description
The entire file contents, loaded to memory.
Currently, the implementation does not load everything to memory, but it
should and will do so in the future. To load only a summary, use the
BraidzSummary type. Currently, a summary can only be made by loading the
entire archive first, but more efficient path can be made later.
Fields
metadata: BraidMetadataexpected_fps: f64calibration_info: Option<CalibrationInfo>kalman_estimates_info: Option<KalmanEstimatesInfo>kalman_estimates_table: Option<Vec<KalmanEstimatesRow>>data_association: Option<Vec<DataAssocRow>>reconstruction_latency_hlog: Option<HistogramLog>reprojection_distance_hlog: Option<HistogramLog>cam_info: CamInfodata2d_distorted: Option<D2DInfo>image_sizes: Option<BTreeMap<String, (usize, usize)>>A mapping from camera name to (width, height).
Implementations
Sourceimpl<R: Read + Seek> BraidzArchive<R>
impl<R: Read + Seek> BraidzArchive<R>
Sourcepub fn into_inner(self) -> ZipDirArchive<R>
pub fn into_inner(self) -> ZipDirArchive<R>
Consume and return the raw storage archive.
Sourceimpl<'a, R: Read + Seek> BraidzArchive<R>
impl<'a, R: Read + Seek> BraidzArchive<R>
Sourcepub fn iter_data2d_distorted(
&'a mut self,
) -> Result<impl Iterator<Item = Result<Data2dDistortedRow, Error>> + 'a, Error>
pub fn iter_data2d_distorted( &'a mut self, ) -> Result<impl Iterator<Item = Result<Data2dDistortedRow, Error>> + 'a, Error>
Iterate over the rows of the data2d_distorted table.
This takes a mutable reference because the read location in the archive is changed during operation.
Note that, as described in the “Details about how data are processed online and saved for later analysis” section in the “3D Tracking in Braid” chapter of the User’s Guide, these will not, in general, be returned in a monotonically increasing order.
Sourcepub fn iter_grouped_data2d_distorted(
&'a mut self,
include_nan_data: bool,
bufsize: usize,
) -> Result<impl Iterator<Item = Result<GroupedRows<i64, Data2dDistortedRow>, Error>> + 'a, Error>
pub fn iter_grouped_data2d_distorted( &'a mut self, include_nan_data: bool, bufsize: usize, ) -> Result<impl Iterator<Item = Result<GroupedRows<i64, Data2dDistortedRow>, Error>> + 'a, Error>
Iterate over synchronized frames in data2d_distorted table.
This sorts the data by looking ahead up to bufsize rows. Furthermore,
it can exclude nan data if include_nan_data is set to false. No
guarantees are made about whether frames may be skipped and indeed they
often may be.