pub struct Seq2d {
pub frame: Vec<i64>,
pub xdata: Vec<NotNan<f64>>,
pub ydata: Vec<NotNan<f64>>,
pub max_pixel: NotNan<f64>,
pub timestamp_trigger: Vec<Option<FlydraFloatTimestampLocal<Triggerbox>>>,
pub timestamp_host: Vec<FlydraFloatTimestampLocal<HostClock>>,
}Expand description
Column store for 2D detections for a single camera.
Note that these are not filled when there is no detection.
Fields
frame: Vec<i64>The frame number in the synchronized, global frame count.
xdata: Vec<NotNan<f64>>The x coordinate of the detections.
ydata: Vec<NotNan<f64>>The y coordinate of the detections.
max_pixel: NotNan<f64>The maximum value of all x and y coordinates.
timestamp_trigger: Vec<Option<FlydraFloatTimestampLocal<Triggerbox>>>The time at which the hardware trigger was computed to have fired to initiate image acquisition at this frame.
This is computed based on a model of the clock running on the triggerbox and keeping this model updated via continual sampling of both the triggerbox clock and the system clock of the computer hosting the triggerbox.
timestamp_host: Vec<FlydraFloatTimestampLocal<HostClock>>The time at which the image was available to the system clock of the host computer of the camera.